import request from '@/utils/request'

// 查询班级管理列表
export function listClass(query) {
  return request({
    url: '/school/class/list',
    method: 'get',
    params: query
  })
}

// 查询班级管理详细
export function getClass(classId) {
  return request({
    url: '/school/class/' + classId,
    method: 'get'
  })
}

// 新增班级管理
export function addClass(data) {
  return request({
    url: '/school/class',
    method: 'post',
    data: data
  })
}

// 修改班级管理
export function updateClass(data) {
  return request({
    url: '/school/class/'+data.classId,
    method: 'put',
    data: data
  })
}

// 删除班级管理
export function delClass(classId) {
  return request({
    url: '/school/class/' + classId,
    method: 'delete'
  })
}

//无条件查询班级管理
export function findUnconditional() {
  return request({
    url: '/school/class/findUnconditional',
    method: 'get'
  })
}

//查看小组信息
export function findGroup(data) {
  return request({
    url: '/group/group/list',
    method: 'get',
    data
  })
}

//添加小祖
export function addGroup(data) {
  return request({
    url: '/group/group/saveGroup',
    method: 'post',
    data
  })
}
// 删除小组管理
export function delGroup(groupId) {
  return request({
    url: '/group/group/' + groupId,
    method: 'delete'
  })
}
// 修改小组管理
export function updateGroup(data) {
  return request({
    url: '/group/group/'+data.groupId,
    method: 'put',
    data: data
  })
}
