<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="班级名称" prop="className">
        <el-input
          v-model="queryParams.className"
          placeholder="请输入班级名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="班级状态" prop="classState">
        <el-select v-model="queryParams.classState" placeholder="请选择班级状态  1 - 未开班  2 - 开班" clearable>
          <el-option
            v-for="dict in dict.type.clazz_on_off"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value"
          />
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['school:class:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['school:class:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['school:class:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['school:class:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

<!--    查看小组信息-->
    <el-dialog title="小组管理" :visible.sync="dialogTableVisible" @selection-change="handleSelectionChangegroup">
      <el-button type="success" @click="handleAddGroup" icon="el-icon-plus" circle style="position: absolute; top: 10px; right: 10px;">新增</el-button>

      <el-table :data="groupList" style="width: 100%">

        <el-table-column label="小组序号" width="180">
          <template slot-scope="scope">
            <span style="margin-left: 10px">{{ scope.row.groupId }}</span>
          </template>
        </el-table-column>

        <el-table-column label="小组名称" width="180">
          <template slot-scope="scope">
            <span style="margin-left: 10px">{{ scope.row.groupName }}</span>
          </template>
        </el-table-column>

        <el-table-column label="小组人数" width="180">
          <template slot-scope="scope">
            <span style="margin-left: 10px">{{ scope.row.groupPeople }}</span>
          </template>
        </el-table-column>

        <el-table-column label="小组人员" width="180">
          <template slot-scope="scope">
            <span style="margin-left: 10px">{{ scope.row.groupPersonnel }}</span>
          </template>
        </el-table-column>

        <el-table-column label="操作">
          <template slot-scope="scope">
            <el-button size="mini" @click="handleEdit(scope.row)">编辑</el-button>
            <el-button size="mini" type="danger" @click="handleDeletegroup(scope.row)">删除</el-button>
          </template>
        </el-table-column>
      </el-table>


      <!--    小组列表分也-->
      <pagination
        v-show="grouptotal>0"
        :total="grouptotal"
        :page.sync="queryGroup.pageNum"
        :limit.sync="queryGroup.pageSize"
        @pagination="findByGroup"
      />
    </el-dialog>



    <!-- 添加或修改小组管理对话框 -->
    <el-dialog :title="title" :visible.sync="addupdate" width="500px" append-to-body>
      <el-form ref="form" :model="group" :rules="rules" label-width="80px">
        <el-form-item label="小组名称" prop="groupName">
          <el-input v-model="group.groupName" placeholder="请输入小组名称" />
        </el-form-item>
        <el-form-item label="小组人数" prop="groupPeople">
          <el-input v-model="group.groupPeople" placeholder="请输入小组人数" />
        </el-form-item>
        <el-form-item label="小组人员" prop="groupPersonnel">
          <el-input v-model="group.groupPersonnel" placeholder="请输入小组人员" />
        </el-form-item>
        <el-form-item label="班级">
          <el-select v-model="group.classId" placeholder="请选择班级">
            <el-option v-for="item in classDown" :label="item.className" :value="item.classId"></el-option>
          </el-select>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitFormgroup">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>


    <el-table v-loading="loading" :data="classList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="班级ID" align="center" prop="classId" />
      <el-table-column label="班级名称" align="center" prop="className" />
      <el-table-column label="班级状态" align="center" prop="classState">
        <template slot-scope="scope">
          <dict-tag :options="dict.type.clazz_on_off" :value="scope.row.classState"/>
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">

          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['school:class:edit']"
          >修改</el-button>

          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="findByGroup(scope.row.classId)"
            v-hasPermi="['school:class:edit']"
          >查看小组</el-button>

          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['school:class:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改班级管理对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="班级名称" prop="className">
          <el-input v-model="form.className" placeholder="请输入班级名称" />
        </el-form-item>
        <el-form-item label="班级状态  1 - 未开班  2 - 开班" prop="classState">
          <el-select v-model="form.classState" placeholder="请选择班级状态  1 - 未开班  2 - 开班">
            <el-option
              v-for="dict in dict.type.clazz_on_off"
              :key="dict.value"
              :label="dict.label"
              :value="parseInt(dict.value)"
            ></el-option>
          </el-select>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {
  listClass,
  getClass,
  delClass,
  addClass,
  updateClass,
  findGroup,
  findUnconditional,
  addGroup, updateGroup, delGroup
} from "@/api/school/class";

export default {
  name: "Class",
  dicts: ['clazz_on_off'],
  data() {
    return {
      // 选中数组
      idss: [],
      // 非单个禁用
      singles: true,
      // 非多个禁用
      multiples: true,
      // xiaozu总条数
      grouptotal: 0,
      //小组查询
      queryGroup:{
        pageNum: 1,
        pageSize: 5,
        classId: 0,
      },
      // 表单参数
      group: {},
      //显示弹出窗
      addupdate:false,
      //存储班级下拉
      classDown:[],
      //展示小组管理列表
      dialogTableVisible: false,
      //小组集合
      groupList:[],
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 班级管理表格数据
      classList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        className: null,
        classState: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
      }
    };
  },
  created() {
    this.getList();
    this.queryAllClasslist();
  },
  methods: {
    handleDeletegroup(row)
    {
      const groupIds = row.groupId || this.ids;
      this.$modal.confirm('是否确认删除小组管理编号为"' + groupIds + '"的数据项？').then(function() {
        return delGroup(groupIds);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    // 多选框选中数据
    handleSelectionChangegroup(selection) {
      this.idss = selection.map(item => item.groupId)
      this.singles = selection.length!==1
      this.multiples = !selection.length
    },
    handleEdit(row){
      this.resetgroup();
      this.group = row
      this.addupdate = true;
      this.title = "修改小组管理";
    },
    /** 提交按钮 */
    submitFormgroup() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.group.groupId != null) {
            updateGroup(this.group).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.addupdate = false;
              this.queryGroup();
            });
          } else {
            addGroup(this.group).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.addupdate = false;
              this.queryGroup();
            });
          }
        }
      });
    },
    // 表单重置
    resetgroup() {
      this.group = {
        groupId: null,
        groupName: null,
        groupPeople: null,
        groupPersonnel: null,
        classId: null
      }
    },
    handleAddGroup(){
      this.resetgroup();
      this.addupdate = true;
      this.title = "添加小组管理";
    },
    //无条件查询班级管理下拉
    queryAllClasslist(){
      findUnconditional().then(res=>{
        this.classDown = res.data.rows
      })
    },
    findByGroup(classId){
      this.queryGroup.classId = classId
      findGroup(this.queryGroup).then(res=>{
        this.dialogTableVisible = true
        this.grouptotal = res.data.total
        this.groupList = res.data.rows
      })
    },
    /** 查询班级管理列表 */
    getList() {
      this.loading = true;
      listClass(this.queryParams).then(response => {
        this.classList = response.data.rows;
        this.total = response.data.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        classId: null,
        className: null,
        classState: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.classId)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加班级管理";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const classId = row.classId || this.ids
      getClass(classId).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改班级管理";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.classId != null) {
            updateClass(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addClass(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const classIds = row.classId || this.ids;
      this.$modal.confirm('是否确认删除班级管理编号为"' + classIds + '"的数据项？').then(function() {
        return delClass(classIds);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('school/class/export', {
        ...this.queryParams
      }, `class_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
